

TI Vendor Map Audit Generation Profiling
****************************************

.. seealso:: :func:`profiling.sourcing.vendors.profile_vendor_genvmapaudit`

:download:`Raw execution profile <../../../profiling/sourcing/genvmapaudit/ti.profile>`
:download:`SVG of execution profile <../../../profiling/sourcing/genvmapaudit/ti.profile.svg>`

    .. rubric:: Execution Profile

    .. image:: ../../../profiling/sourcing/genvmapaudit/ti.profile.svg

    .. rubric:: pstats Output

    .. literalinclude:: ../../../profiling/sourcing/genvmapaudit/ti.profile.stats

